@@ -1,20 +1,30 @@
-"""Schema module for a generic wetlab (`vvhc`).
+"""Base classes for a wetlab schema (`vvhc`).
 
 Import the package::
 
    import lnschema_wetlab
 
-This is the complete API reference:
+Base classes:
+
+.. autosummary::
+   :toctree: .
+
+   ExperimentBase
+   ExperimentTypeBase
+   BiosampleBase
+   TechsampleBase
+   ReadoutBase
+
+Examples of derived classes, typically configured:
 
 .. autosummary::
    :toctree: .
 
-   Biosample
-   Techsample
-   Readout
-   Treatment
    Experiment
-   ExperimentType
+   ExperimentTypeBase
+   BiosampleBase
+   TechsampleBase
+   ReadoutBase
 
 Development tools:
 
@@ -29,14 +39,18 @@ Development tools:
 _schema_id = "vvhc"
 _name = "wetlab"
 _migration = "bfda12fc80a8"
-__version__ = "0.11.4"
+__version__ = "0.12.0"
 
 from . import dev, link
 from ._core import (  # noqa
     Biosample,
+    BiosampleBase,
     Experiment,
+    ExperimentBase,
     ExperimentType,
+    ExperimentTypeBase,
     Readout,
+    ReadoutBase,
     Techsample,
-    Treatment,
+    TechsampleBase,
 )
